pub fn load_user_env() -> Result<HashMap<String, String>, CoreError>Expand description
Load credentials from config file and set environment variables.
This hydrates environment variables from the stored config file, making credentials available to the current process.
Returns
Map of variable names to values that were set.